@@ -1,16 +1,17 @@
 //! # `jamsocket-cli`: a command-line interface to Jamsocket
 
-use clap::Clap;
-use env_logger::Builder;
+use clap::Parser;
 use jamsocket_cli::cli_opts::{Opts, SubCommand};
 use jamsocket_cli::{dev, serve};
+use tracing_subscriber::EnvFilter;
 
 fn main() -> anyhow::Result<()> {
-    let mut builder = Builder::new();
-    builder.filter(Some("jamsocket_cli"), log::LevelFilter::Info);
-    builder.filter(Some("jamsocket_server"), log::LevelFilter::Info);
-    builder.filter(Some("jamsocket_wasm_host"), log::LevelFilter::Info);
-    builder.init();
+    let env_filter = EnvFilter::default()
+        .add_directive("jamsocket_cli=info".parse()?)
+        .add_directive("jamsocket_wasm_host=info".parse()?)
+        .add_directive("jamsocket_server=info".parse()?);
+
+    tracing_subscriber::fmt().with_env_filter(env_filter).init();
 
     let opts = Opts::parse();
 
